Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(382)

Unified Diff: runtime/observatory/lib/service_common.dart

Issue 1077823003: Some cleanups in the code that posts results to service clients. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/vmservice/server.dart ('k') | runtime/vm/debugger.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/observatory/lib/service_common.dart
diff --git a/runtime/observatory/lib/service_common.dart b/runtime/observatory/lib/service_common.dart
index 3add11599f9bc002ff233fe44aa5105ce22f01ac..c47d2b37c02df05e9f9008aa89f19a17c57a85ae 100644
--- a/runtime/observatory/lib/service_common.dart
+++ b/runtime/observatory/lib/service_common.dart
@@ -186,15 +186,15 @@ abstract class CommonWebSocketVM extends VM {
Logger.root.severe('WebSocketVM got empty message');
return;
}
// Extract serial and response.
var serial;
- var response;
+ var result;
serial = map['id'];
- response = map['response'];
+ result = map['result'];
if (serial == null) {
// Messages without serial numbers are asynchronous events
// from the vm.
- postServiceEvent(response, null);
+ postServiceEvent(result, null);
return;
}
// Complete request.
@@ -209,7 +209,7 @@ abstract class CommonWebSocketVM extends VM {
Logger.root.info(
'RESPONSE [${serial}] ${request.method}');
}
- request.completer.complete(response);
+ request.completer.complete(result);
}
// WebSocket message event handler.
« no previous file with comments | « runtime/bin/vmservice/server.dart ('k') | runtime/vm/debugger.cc » ('j') | no next file with comments »
@@ -186,15 +186,15 @@ abstract class CommonWebSocketVM extends VM {
return;
}
- // Extract serial and response.
+ // Extract serial and result.
var serial;

Powered by Google App Engine
This is Rietveld 408576698